package javax.swing.tree;

import javax.swing.event.TreeModelEvent;
import java.util.Enumeration;
import java.awt.Rectangle;

public abstract class AbstractLayoutCache implements RowMapper
{
    protected AbstractLayoutCache.NodeDimensions nodeDimensions;
    protected TreeModel treeModel;
    protected TreeSelectionModel treeSelectionModel;
    protected boolean rootVisible;
    protected int rowHeight;
    
    public AbstractLayoutCache() {
    }
    
    public void setNodeDimensions(AbstractLayoutCache.NodeDimensions nodeDimensions) {
        this.nodeDimensions = nodeDimensions;
    }
    
    public AbstractLayoutCache.NodeDimensions getNodeDimensions() {
        return this.nodeDimensions;
    }
    
    public void setModel(TreeModel treeModel) {
        this.treeModel = treeModel;
    }
    
    public TreeModel getModel() {
        return this.treeModel;
    }
    
    public void setRootVisible(boolean rootVisible) {
        this.rootVisible = rootVisible;
    }
    
    public boolean isRootVisible() {
        return this.rootVisible;
    }
    
    public void setRowHeight(int rowHeight) {
        this.rowHeight = rowHeight;
    }
    
    public int getRowHeight() {
        return this.rowHeight;
    }
    
    public void setSelectionModel(TreeSelectionModel treeSelectionModel) {
        if (this.treeSelectionModel != null) {
            this.treeSelectionModel.setRowMapper(null);
        }
        this.treeSelectionModel = treeSelectionModel;
        if (this.treeSelectionModel != null) {
            this.treeSelectionModel.setRowMapper(this);
        }
    }
    
    public TreeSelectionModel getSelectionModel() {
        return this.treeSelectionModel;
    }
    
    public int getPreferredHeight() {
        int rowCount = this.getRowCount();
        if (rowCount > 0) {
            Rectangle bounds = this.getBounds(this.getPathForRow(rowCount - 1), null);
            if (bounds != null) {
                return bounds.y + bounds.height;
            }
        }
        return 0;
    }
    
    public int getPreferredWidth(Rectangle rectangle) {
        if (this.getRowCount() > 0) {
            TreePath treePath;
            int n;
            if (rectangle == null) {
                treePath = this.getPathForRow(0);
                n = Integer.MAX_VALUE;
            }
            else {
                treePath = this.getPathClosestTo(rectangle.x, rectangle.y);
                n = rectangle.height + rectangle.y;
            }
            Enumeration<TreePath> visiblePaths = this.getVisiblePathsFrom(treePath);
            if (visiblePaths != null && visiblePaths.hasMoreElements()) {
                Rectangle rectangle2 = this.getBounds((TreePath)visiblePaths.nextElement(), null);
                int max;
                if (rectangle2 != null) {
                    max = rectangle2.x + rectangle2.width;
                    if (rectangle2.y >= n) {
                        return max;
                    }
                }
                else {
                    max = 0;
                }
                while (rectangle2 != null && visiblePaths.hasMoreElements()) {
                    rectangle2 = this.getBounds((TreePath)visiblePaths.nextElement(), rectangle2);
                    if (rectangle2 != null && rectangle2.y < n) {
                        max = Math.max(max, rectangle2.x + rectangle2.width);
                    }
                    else {
                        rectangle2 = null;
                    }
                }
                return max;
            }
        }
        return 0;
    }
    
    public abstract boolean isExpanded(TreePath p0);
    
    public abstract Rectangle getBounds(TreePath p0, Rectangle p1);
    
    public abstract TreePath getPathForRow(int p0);
    
    public abstract int getRowForPath(TreePath p0);
    
    public abstract TreePath getPathClosestTo(int p0, int p1);
    
    public abstract Enumeration<TreePath> getVisiblePathsFrom(TreePath p0);
    
    public abstract int getVisibleChildCount(TreePath p0);
    
    public abstract void setExpandedState(TreePath p0, boolean p1);
    
    public abstract boolean getExpandedState(TreePath p0);
    
    public abstract int getRowCount();
    
    public abstract void invalidateSizes();
    
    public abstract void invalidatePathBounds(TreePath p0);
    
    public abstract void treeNodesChanged(TreeModelEvent p0);
    
    public abstract void treeNodesInserted(TreeModelEvent p0);
    
    public abstract void treeNodesRemoved(TreeModelEvent p0);
    
    public abstract void treeStructureChanged(TreeModelEvent p0);
    
    @Override
    public int[] getRowsForPaths(TreePath[] array) {
        if (array == null) {
            return null;
        }
        int length = array.length;
        int[] array2 = new int[length];
        for (int i = 0; i < length; ++i) {
            array2[i] = this.getRowForPath(array[i]);
        }
        return array2;
    }
    
    protected Rectangle getNodeDimensions(Object o, int n, int n2, boolean b, Rectangle rectangle) {
        AbstractLayoutCache.NodeDimensions nodeDimensions = this.getNodeDimensions();
        if (nodeDimensions != null) {
            return nodeDimensions.getNodeDimensions(o, n, n2, b, rectangle);
        }
        return null;
    }
    
    protected boolean isFixedRowHeight() {
        return this.rowHeight > 0;
    }
    
    public abstract static class NodeDimensions
    {
        public abstract Rectangle getNodeDimensions(Object p0, int p1, int p2, boolean p3, Rectangle p4);
    }
}
